###############################################################
# Replicatiion File
# of
# "Measuring Judicial Independence Reconsidered: 
# Survival Analysis, Matching, and Average Treatment Effects"
# by
# Kentaro Fukumoto (Kentaro.Fukumoto@gakushuin.ac.jp)
# and
# Mikitaka Masuyama (mmasuyama@grips.ac.jp)
###############################################################

setwd("script")

############################################
# Replicate Ramseyer and Rasmusen's analysis

# Please prepare Ramseyer and Rasmusen's data file, "sokatsu4.dta".
# We downloaded it from
# http://www.rasmusen.org/published/jbook/jbook.htm
# http://www.rasmusen.org/published/jbook/apsr2001.htm
# though we can do it now.

library(foreign)
data.original <- read.dta("../data/sokatsu4.dta")
# dismiss warnings

# Table 1, left panel
lm.original <-  lm(Y2S_Cor ~ yjl + FstTok + flunk + eliteu + 
 a1959 + a1960 + a1961 + a1962 + a1963 + a1964+ a1965 + a1966 + a1967,
 data=data.original)

###############################################################
# Reanalysis of corrected version data of Ramseyer and Rasmusen

data.corrected <- data.original
source("correct.r")

# the number of corrected observations
nrow(fix.time)
nrow(fix.yjl)
nrow(fix.flunk)
nrow(fix.eliteu)
# no change for FstTok 

# Table 1, right panel
lm.corrected <-  lm(Y2S_Cor ~ yjl + FstTok + flunk + eliteu + 
                     a1959 + a1960 + a1961 + a1962 + a1963 + a1964+ a1965 + a1966 + a1967,
                   data=data.corrected)

# Tables 1 and 2
source("table.1&2.r")
round(table.1,3)
round(table.2,3)

##########
# Matching

judge <- read.csv("../data/extended.data.csv")
source("extend.r")

# the number of observations
dim(judge)

# the number of judges
length(unique(judge[,"id"]))

# summary of "Time_Chief"
summary(judge$NY2S1)

## IF you want to make matched data by yourself, run
#  source("matching.r")
## though it takes a few days.
## Instead, we recommend you use ready-made matched pair
load("../data/matching.out.Rdata")
judge.match <- rbind(judge[id.treat,],judge[id.control,])

# the number of matched pairs
length(id.treat)

# mean of treated and controled observations before and after matching",
source("balance.r")
round(balance,3)
# For some variables, balance is prefect.
round(balance[perfect==1,],3)
# Even for the worst balanced variable, Flunks, its balance is improved.
rownames(balance)[worst]
round(balance[worst,],2)

# Figure 1
# Distributions of propensity scores 
source("figure1.r")

# Figure 2
# Life table 
library(survival)
source("figure2.r")

###################################
# Average treatment effect on event

tie.event <- make.tie.event(judge.match$delta)
TE.event <- tie.event[,1]- tie.event[,2]

# the number of pairs
length(TE.event)
# ATE
mean(TE.event)
# Standard error by central limiting theorem
sqrt(var(TE.event)/length(TE.event))
# p-value
2*(1-pnorm(abs(mean(TE.event)/sqrt(var(TE.event)/length(TE.event)))))

##################################
# Average treatment effect on time

tie.time <- make.tie.time(judge.match$NY2S1,judge.match$delta)
TE.time <- tie.time[,1]- tie.time[,2]

# the number of pairs
length(TE.time)
# ATE
mean(TE.time)
# Standard error by central limiting theorem
sqrt(var(TE.time)/length(TE.time))
# p-value
2*(1-pnorm(abs(mean(TE.time)/sqrt(var(TE.time)/length(TE.time)))))

#################
# Table 3
# chi square test

source("table.3.r")
# chi square test
chisq.test(table.3,correct=F)

###################
# Table 4
# Survival analysis

attach(judge.match)
source("splitLeft.r")

Left.out <- main.left(
NY2S1 ~ nyjl + nFstTok + nflunk + neliteu +
 A1959 + A1960 + A1961 + A1962 + A1963 + A1964 + A1965 + A1966 + A1967,
delta ~ nyjl + nFstTok + nflunk + neliteu + 
 A1959 + A1960 + A1961 + A1962 + A1963 + A1964 + A1965 + A1966 + A1967,
begin)

## IF you want to do bootstrap by yourself, run
#  source("bootstrap.r")
## though it takes a few days.
## Instead, we recommend you use ready-made matched data 
load("../data/bootstrap.out.Rdata")
source("table.4.r")

